@@ -1,6 +1,6 @@
 /*
-**  Sinek (Video Player)
-**  Copyright (c) 2001 the Sinek Team, see the AUTHORS file.
+**  Sinek (Media Player)
+**  Copyright (c) 2001-2002 Gurer Ozen
 **
 **  This code is free software; you can redistribute it and/or
 **  modify it under the terms of the GNU General Public License.
@@ -21,12 +21,13 @@
 #        define N_(String) (String)
 #    endif
 #else
-/* Stubs that do something close enough.  */
+/* Stubs that do something close enough. */
 #    define textdomain(String) (String)
 #    define gettext(String) (String)
 #    define dgettext(Domain,Message) (Message)
 #    define dcgettext(Domain,Message,Type) (Message)
 #    define bindtextdomain(Domain,Directory) (Domain)
+#    define bind_textdomain_codeset(Domain, Codeset)
 #    define _(String) (String)
 #    define N_(String) (String)
 #endif
